PagePreviewStyle class

Configuration for the preview displayed when showSidePagePreviews is true.

Constructors

PagePreviewStyle({Widget? leftPagePreviewWidget, Widget? rightPagePreviewWidget, Widget? topPagePreviewWidget, Widget? bottomPagePreviewWidget, String leftPageLabel = "Left", String rightPageLabel = "Right", String topPageLabel = "Top", String bottomPageLabel = "Bottom", Color defaultChipBackgroundColor = const Color(0xCC424242), Color defaultChipTextColor = Colors.white, EdgeInsets defaultChipPadding = const EdgeInsets.symmetric(horizontal: 16.0, vertical: 8.0), BorderRadius defaultChipBorderRadius = const BorderRadius.all(Radius.circular(20.0)), TextStyle? defaultChipTextStyle, double previewOffsetFromEdge = 20.0, double? previewAppearanceThreshold = 0.15, double previewMinScale = 0.8, double previewMaxScale = 1.0, double previewScaleBeyondThresholdFactor = 1.1})
const

Properties

bottomPageLabel String
final
bottomPagePreviewWidget Widget?
final
defaultChipBackgroundColor Color
final
defaultChipBorderRadius BorderRadius
final
defaultChipPadding EdgeInsets
final
defaultChipTextColor Color
final
defaultChipTextStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
leftPageLabel String
final
leftPagePreviewWidget Widget?
final
previewAppearanceThreshold double?
final
previewMaxScale double
final
previewMinScale double
final
previewOffsetFromEdge double
final
previewScaleBeyondThresholdFactor double
final
rightPageLabel String
final
rightPagePreviewWidget Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topPageLabel String
final
topPagePreviewWidget Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited