PageWrapper class

A wrapper widget for the pages displayed as side pages in the FivePageNavigator. Handles system back button and optional swipe-back gesture.

Inheritance

Constructors

PageWrapper({Key? key, required Widget child, required PageType pageType, dynamic onReturnFromPage(PageType returnedFrom)?, bool enableSwipeBack = false, required Widget centerPage, ThresholdFeedback thresholdFeedback = ThresholdFeedback.heavyImpact, bool showReturnToCenterButton = true, ReturnButtonConfig? returnButtonConfig, double incomingPageOpacityStart = 0.1})
const

Properties

centerPage Widget
final
child Widget
final
enableSwipeBack bool
final
hashCode int
The hash code for this object.
no setterinherited
incomingPageOpacityStart double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onReturnFromPage → dynamic Function(PageType returnedFrom)?
final
pageType PageType
final
returnButtonConfig ReturnButtonConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showReturnToCenterButton bool
final
thresholdFeedback ThresholdFeedback
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PageWrapper>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited